@@ -1,12 +1,8 @@
 .bcParamValid <-
-function (y.miss, by.miss, facet1.miss, Trellis, sort,
+function (y.miss, by.miss, facet.miss, Trellis, sort,
           fill_split, fill_scaled, fill_chroma, theme,
           fill.miss, labels_position, stat.miss) {
 
-  if (!by.miss  &&  !facet1.miss) {
-    cat("\n"); stop(call.=FALSE, "\n","------\n",
-      "by  and  facet1  parameters not currently available at the same time.\n\n")
-  }
 
   if (Trellis  &&  sort != "0") {
     cat("\n"); stop(call.=FALSE, "\n","------\n",
@@ -29,16 +25,11 @@ function (y.miss, by.miss, facet1.miss, Trellis, sort,
       "labels_position  must be set to \"in\", \"out\"\n\n")
   }
 
-  if (!stat.miss && y.miss) {
-    cat("\n"); stop(call.=FALSE, "\n","------\n",
-      "parameter  stat  is meaningless if no y-variable to transform\n\n")
-  }
-
   if (!stat.miss && Trellis) {
     cat("\n"); stop(call.=FALSE, "\n","------\n",
       "Only the original data work with Trellis plots,",
       " no data aggregation with parameter stat.",
-      " Use  by  instead of  facet1.\n\n")
+      " Use  by  instead of  facet.\n\n")
   }
 
 }
