@@ -12,15 +12,17 @@ print.out_all <- function(x, ...) {
         else 
           cat("\n")
 
-        if (substr(names(x[ilist]),5,9) != "title")
-          for (i in 1:length(x[[ilist]])) cat(x[[ilist]][i], "\n")
-        else
+        if (substr(names(x[ilist]),5,9) != "title") {
+          if (!is.data.frame(x[[ilist]]))
+            for (i in 1:length(x[[ilist]])) cat(x[[ilist]][i], "\n")
+          else  # a data frame
+            print(x[[ilist]], row.names=FALSE)  # first done plt.txt, #402
+        }  # not a title
+        else  # a title
           cat(x[[ilist]], "\n") 
-      }
 
+      }  # end nzchar()
     }  # end out_ condition
   }  # end ilist loop
-
-# cat("\n")
-
 }
+
